@@ -1,7 +1,8 @@
-# -*- coding: UTF-8 -*-
+from __future__ import annotations
+
 from django import forms
 
-from generic_link.models import GenericLink
+from generic_links.models import GenericLink
 
 
 class AddLinkForm(forms.ModelForm):
@@ -13,14 +14,16 @@ class AddLinkForm(forms.ModelForm):
         self.user = user
         self.content_type = content_type
         self.object_id = object_id
-        super(AddForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def save(self, *args, **kwargs):
-        self.instance, created = GenericLink.objects.create(
-            content_type=self.content_type, object_id=self.object_id,
+        self.instance = GenericLink.objects.create(
+            content_type=self.content_type,
+            object_id=self.object_id,
             url=self.cleaned_data["url"].strip(),
-            title=self.cleaned_data["title"], user=self.user,
-            is_approved=self.cleaned_data["is_external"])
+            title=self.cleaned_data["title"],
+            user=self.user,
+            is_external=self.cleaned_data["is_external"],
+        )
 
         return self.instance
-
