@@ -1,7 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Several usefull template tags!
 """
+from __future__ import annotations
+
 from django import template
 
 from generic_links import utils
@@ -11,15 +12,19 @@ register = template.Library()
 
 
 class RelatedLinksNode(template.Node):
-
-    def __init__(self, context_var, obj):
+    def __init__(self, context_var, obj, is_external):
         self.context_var = context_var
         self.obj_var = template.Variable(obj)
+        self.is_external = is_external
 
     def render(self, context):
         obj = self.obj_var.resolve(context)
-        context[self.context_var] = utils.get_links_for(obj).select_related("user")
-        return u""
+        context[self.context_var] = (
+            utils.get_links_for(obj)
+            .select_related("user")
+            .filter(is_external=self.is_external)
+        )
+        return ""
 
 
 @register.tag
@@ -34,9 +39,4 @@ def get_links_for(parser, token):
         message = "'%s' tag requires three arguments" % bits[0]
         raise template.TemplateSyntaxError(message)
 
-    return RelatedLinksNode(bits[3], bits[1])
-
-"""
-Usage: {% get_links_for <obj> owned by <user> as <some_var> %}
-Usage: {% get_external_links_for <obj> owned by <user> as <some_var> %}
-"""
+    return RelatedLinksNode(bits[3], bits[1], True)
